@@ -1,42 +1,53 @@
 use std::fs;
 
-use clap::{AppSettings, Clap};
 use structopt::StructOpt;
 
-use modeling::{by_dir};
-use modeling::render::{MermaidRender, PlantUmlRender};
+use modeling::{by_dir, ParseOption};
 use modeling::file_filter::FileFilter;
+use modeling::render::{MermaidRender, PlantUmlRender};
 
-#[derive(StructOpt, Debug, Clap)]
-#[clap(version = "1.0", author = "Inherd Group <group@inherd.org>")]
-#[clap(setting = AppSettings::ColoredHelp)]
+#[derive(StructOpt, Debug, PartialEq)]
 #[structopt(name = "basic")]
 struct Opts {
+    /// merge for same method name
+    #[structopt(short, long)]
+    merge: bool,
+
     /// input dir
-    #[clap(short, long, default_value = ".")]
+    #[structopt(short, long, default_value = ".")]
     input: String,
 
     /// mermaid or puml
-    #[clap(short, long, default_value = "puml")]
+    #[structopt(short, long, default_value = "puml")]
     output_type: String,
 
     // filter dir
-    #[clap(long, short, use_delimiter = true)]
+    #[structopt(long, short, use_delimiter = true)]
     packages: Vec<String>,
 
     // filter suffixes
-    #[clap(long, short, use_delimiter = true)]
+    #[structopt(long, short, use_delimiter = true)]
     suffixes: Vec<String>,
 }
 
+impl Opts {
+    pub fn to_parse_option(&self) -> ParseOption {
+        ParseOption {
+            merge: self.merge
+        }
+    }
+}
+
 fn main() {
-    let opts: Opts = Opts::parse();
+    let opts: Opts = Opts::from_args();
+
     println!("Input path: {:?}", opts.input);
     println!("packages: {:?}", opts.packages);
     println!("suffixes: {:?}", opts.suffixes);
 
+    let parse_option = opts.to_parse_option();
     let filter = FileFilter::new(opts.packages, opts.suffixes);
-    let classes = by_dir(opts.input, filter);
+    let classes = by_dir(opts.input, filter, parse_option);
 
     match opts.output_type.as_str() {
         "mermaid" => {
